@@ -1598,6 +1598,7 @@ class METADATA_STORE:
     SYSTEM_IDENTIFICATION_JOBS_TABLE = "system_identification_jobs"
     DATA_COLLECTION_JOBS_TABLE = "data_collection_jobs"
     MULTI_THRESHOLD_STOPPING_POLICIES_TABLE = "multi_threshold_stopping_policies"
+    LINEAR_THRESHOLD_STOPPING_POLICIES_TABLE = "linear_threshold_stopping_policies"
     PPO_POLICIES_TABLE = "ppo_policies"
     GAUSSIAN_MIXTURE_SYSTEM_MODELS_TABLE = "gaussian_mixture_system_models"
     TABULAR_POLICIES_TABLE = "tabular_policies"
@@ -1770,6 +1771,7 @@ class T_SPSA:
     a = "a"
     c = "c"
     LAMBDA = "lambda"
+    POLICY_TYPE = "policy_type"
     A = "A"
     EPSILON = "epsilon"
     N = "N"
