@@ -8,7 +8,7 @@ class TrafficConfig:
     A DTO object representing the traffic configuration of an emulation environment
     """
     def __init__(self, node_traffic_configs: List[NodeTrafficConfig],
-                 client_population_config: ClientPopulationConfig):
+                 client_population_config: ClientPopulationConfig) -> None:
         """
         Initializes the DTO
 
@@ -40,8 +40,7 @@ class TrafficConfig:
         """
         obj = TrafficConfig(
             node_traffic_configs=list(map(lambda x: NodeTrafficConfig.from_dict(x), d["node_traffic_configs"])),
-            client_population_config=ClientPopulationConfig.from_dict(d["client_population_config"])
-        )
+            client_population_config=ClientPopulationConfig.from_dict(d["client_population_config"]))
         return obj
 
     def to_dict(self) -> Dict[str, Any]:
