@@ -2,14 +2,15 @@ from typing import List, Dict, Union
 import numpy as np
 import torch
 import math
+import iteround
 from stable_baselines3 import PPO
 from csle_common.dao.training.policy import Policy
 from csle_common.dao.training.agent_type import AgentType
 from csle_common.dao.training.player_type import PlayerType
 from csle_common.dao.simulation_config.state import State
-from csle_common.dao.simulation_config.state_type import StateType
 from csle_common.dao.simulation_config.action import Action
 from csle_common.dao.training.experiment_config import ExperimentConfig
+from csle_common.dao.training.policy_type import PolicyType
 from csle_common.logging.log import Logger
 
 
@@ -47,6 +48,7 @@ class PPOPolicy(Policy):
         self.actions = actions
         self.experiment_config = experiment_config
         self.avg_R = avg_R
+        self.policy_type = PolicyType.PPO
 
     def action(self, o: List[float]) -> Union[int, List[int], np.ndarray]:
         """
@@ -58,19 +60,17 @@ class PPOPolicy(Policy):
         a, _ = self.model.predict(np.array(o), deterministic=False)
         return a
 
-    def probability(self, o: List[float], a) -> Union[int, List[int], np.ndarray]:
+    def probability(self, o: List[float], a: int) -> float:
         """
         Multi-threshold stopping policy
 
         :param o: the current observation
-        :return: the selected action
+        :param o: the action
+        :return: the probability of the action
         """
-        actions, values, log_prob = self.model.policy.forward(obs=torch.tensor(o).to(self.model.device))
-        action = actions[0]
-        if action == a:
-            return math.exp(log_prob)
-        else:
-            return 0
+        prob = math.exp(self.model.policy.get_distribution(obs=torch.tensor([o]).to(self.model.device)).log_prob(
+            actions=torch.tensor(a)).item())
+        return prob
 
     def to_dict(self) -> Dict[str, Union[float, int, str]]:
         """
@@ -92,6 +92,7 @@ class PPOPolicy(Policy):
         d["experiment_config"] = self.experiment_config.to_dict()
         d["agent_type"] = self.agent_type
         d["avg_R"] = self.avg_R
+        d["policy_type"] = self.policy_type
         return d
 
     @staticmethod
@@ -116,22 +117,14 @@ class PPOPolicy(Policy):
         :param o: the latest observation
         :return: the |S|x|A| stage policy
         """
-        b1 = o[1]
-        l = int(o[0])
-        if not self.player_type == PlayerType.ATTACKER:
-            stage_policy = []
-            for _ in self.states:
-                stage_policy.append(self._get_attacker_dist(obs=o))
-            return stage_policy
-        else:
-            stage_policy = []
-            for s in self.states:
-                if s.state_type != StateType.TERMINAL:
-                    o = [l, b1, s.id]
-                    stage_policy.append(self._get_attacker_dist(obs=o))
-                else:
-                    stage_policy.append([0.5, 0.5])
-            return stage_policy
+        stage_strategy = np.zeros((len(self.states), len(self.actions)))
+        for i, s_a in enumerate(self.states):
+            o[0] = s_a
+            for j, a in enumerate(self.actions):
+                stage_strategy[i][j] = self.probability(o=o, a=j)
+            stage_strategy[i] = iteround.saferound(stage_strategy[i], 2)
+            assert round(sum(stage_strategy[i]), 3) == 1
+        return stage_strategy.tolist()
 
     def _get_attacker_dist(self, obs) -> List[float]:
         """
@@ -155,7 +148,7 @@ class PPOPolicy(Policy):
         """
         return f"model: {self.model}, id: {self.id}, simulation_name: {self.simulation_name}, " \
                f"save path: {self.save_path}, states: {self.states}, experiment_config: {self.experiment_config}," \
-               f"avg_R: {self.avg_R}"
+               f"avg_R: {self.avg_R}, policy type: {self.policy_type}"
 
     def to_json_str(self) -> str:
         """
