@@ -1,8 +1,10 @@
 from typing import Union, List, Dict, Any, Optional
+import numpy as np
 from csle_common.dao.training.agent_type import AgentType
 from csle_common.dao.training.player_type import PlayerType
 from csle_common.dao.training.policy import Policy
 from csle_common.dao.simulation_config.action import Action
+from csle_common.dao.training.policy_type import PolicyType
 
 
 class TabularPolicy(Policy):
@@ -32,6 +34,7 @@ class TabularPolicy(Policy):
         self.simulation_name = simulation_name
         self.id = -1
         self.avg_R = avg_R
+        self.policy_type = PolicyType.TABULAR
 
     def action(self, o: Union[List[Union[int, float]], int, float]) -> Union[int, float]:
         """
@@ -40,7 +43,7 @@ class TabularPolicy(Policy):
         :param o: the input observation
         :return: the next action and its probability
         """
-        return self.lookup_table[o].index(1)
+        return np.random.choice(np.arange(0, len(self.lookup_table[int(o)])), p=self.lookup_table[int(o)])
 
     def probability(self, o: Union[List[Union[int, float]], int, float], a: int) -> float:
         """
@@ -83,6 +86,7 @@ class TabularPolicy(Policy):
         d["id"] = self.id
         d["avg_R"] = self.avg_R
         d["q_table"] = self.q_table
+        d["policy_type"] = self.policy_type
         return d
 
     def stage_policy(self, o: Union[List[Union[int, float]], int, float]) -> List[List[float]]:
@@ -101,7 +105,7 @@ class TabularPolicy(Policy):
         return f"agent_type: {self.agent_type}, player_type: {self.player_type}, " \
                f"actions: {list(map(lambda x: str(x), self.actions))}, lookup_table: {self.lookup_table}, " \
                f"value_function: {self.value_function}, simulation_name: {self.simulation_name}, id: {self.id}, " \
-               f"avg_R: {self.avg_R}, q_table: {self.q_table}"
+               f"avg_R: {self.avg_R}, q_table: {self.q_table}, policy_type: {self.policy_type}"
 
     def to_json_str(self) -> str:
         """
